@@ -19,7 +19,7 @@
 #include <uuid/uuid.h>
 #include <stdint.h>
 
-#define DBI_VERSION      0.4.1
+#define DBI_VERSION      0.5.6
 
 namespace dbi {
     struct null {};
@@ -31,8 +31,9 @@ namespace dbi {
 #include "dbic++/container.h"
 #include "dbic++/cpool.h"
 
-#define DEFAULT_DRIVER_PATH "/usr/lib/dbic++"
+#define DEFAULT_DRIVER_PATH "/usr/local/lib/dbic++"
 
+#define DBI_TYPE_UNKNOWN   0
 #define DBI_TYPE_INT       1
 #define DBI_TYPE_TIME      2
 #define DBI_TYPE_TEXT      3
@@ -53,13 +54,15 @@ namespace dbi {
 
 #include "dbic++/util.h"
 #include "dbic++/io.h"
-#include "dbic++/io_stream.h"
-#include "dbic++/io_filestream.h"
+#include "dbic++/string_io.h"
+#include "dbic++/file_io.h"
 #include "dbic++/abstract_handle.h"
 #include "dbic++/abstract_result.h"
 #include "dbic++/abstract_statement.h"
 #include "dbic++/handle.h"
 #include "dbic++/statement.h"
+#include "dbic++/result.h"
+#include "dbic++/query.h"
 #include "dbic++/socketinfo.h"
 
 #endif
